guix-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

55/66: gnu: subversion: Use invoke.


From: Mark H. Weaver
Subject: 55/66: gnu: subversion: Use invoke.
Date: Fri, 23 Mar 2018 04:46:48 -0400 (EDT)

mhw pushed a commit to branch core-updates
in repository guix.

commit 6d0f26123780f665f03e70a5f29d1e3e71b4d2cb
Author: Mark H Weaver <address@hidden>
Date:   Fri Mar 23 03:49:44 2018 -0400

    gnu: subversion: Use invoke.
    
    * gnu/packages/version-control.scm (subversion)[arguments]: Use invoke and
    remove vestigial plumbing in the 'install-perl-bindings' phase.
---
 gnu/packages/version-control.scm | 32 +++++++++++++++-----------------
 1 file changed, 15 insertions(+), 17 deletions(-)

diff --git a/gnu/packages/version-control.scm b/gnu/packages/version-control.scm
index 36dbce4..4aac1fc 100644
--- a/gnu/packages/version-control.scm
+++ b/gnu/packages/version-control.scm
@@ -1106,23 +1106,21 @@ following features:
            (lambda* (#:key outputs #:allow-other-keys)
              ;; Follow the instructions from 
'subversion/bindings/swig/INSTALL'.
              (let ((out (assoc-ref outputs "out")))
-               (and (zero? (system* "make" "swig-pl-lib"))
-                    ;; FIXME: Test failures.
-                    ;; (zero? (system* "make" "check-swig-pl"))
-                    (zero? (system* "make" "install-swig-pl-lib"))
-
-                    ;; Set the right installation prefix.
-                    (with-directory-excursion
-                        "subversion/bindings/swig/perl/native"
-                      (and (zero?
-                            (system* "perl" "Makefile.PL"
-                                     "NO_PERLLOCAL=1"
-                                     (string-append "PREFIX=" out)))
-                           (zero?
-                            (system* "make" "install"
-                                     (string-append "OTHERLDFLAGS="
-                                                    "-Wl,-rpath="
-                                                    out "/lib"))))))))))))
+               (invoke "make" "swig-pl-lib")
+               ;; FIXME: Test failures.
+               ;; (invoke "make" "check-swig-pl")
+               (invoke "make" "install-swig-pl-lib")
+
+               ;; Set the right installation prefix.
+               (with-directory-excursion
+                   "subversion/bindings/swig/perl/native"
+                 (invoke "perl" "Makefile.PL"
+                         "NO_PERLLOCAL=1"
+                         (string-append "PREFIX=" out))
+                 (invoke "make" "install"
+                         (string-append "OTHERLDFLAGS="
+                                        "-Wl,-rpath="
+                                        out "/lib")))))))))
     (native-inputs
       `(("pkg-config" ,pkg-config)
         ;; For the Perl bindings.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]